aboutsummaryrefslogtreecommitdiffstats
path: root/src/scripts
diff options
context:
space:
mode:
authorJack Lloyd <[email protected]>2018-06-15 11:03:26 -0400
committerJack Lloyd <[email protected]>2018-06-15 11:34:23 -0400
commitca62786442635d3f35bff22d22c3dc5521a5c432 (patch)
tree4d33c63c017e9f8ac052d04d61d849b0a36292ae /src/scripts
parentae9b7e89cf9b550e25f8eefa64d0b2733ff6f82e (diff)
TLS would try to negotiate x25519 even if disabled
Also reorder ECC groups to actually match performance characteristics. I'm not sure when P-384 was slower than P-521 but it certainly isn't anymore. Fixes #1607
Diffstat (limited to 'src/scripts')
-rwxr-xr-xsrc/scripts/ci_build.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/scripts/ci_build.py b/src/scripts/ci_build.py
index 18dae66b2..65f62762d 100755
--- a/src/scripts/ci_build.py
+++ b/src/scripts/ci_build.py
@@ -79,9 +79,9 @@ def determine_flags(target, target_os, target_cpu, target_cc, cc_bin, ccache, ro
if target in ['bsi', 'nist']:
# Arbitrarily test disable static on module policy builds
# x509 is optional for bsi/nist but add it so verify tests work with these minimized configs
flags += ['--module-policy=%s' % (target),
- '--enable-modules=x509',
+ '--enable-modules=tls',
'--disable-static']
if target == 'docs':
@@ -79,9 +79,9 @@ def determine_flags(target, target_os, target_cpu, target_cc, cc_bin, ccache, ro
if target in ['bsi', 'nist']:
# Arbitrarily test disable static on module policy builds
- # x509 is optional for bsi/nist but add it so verify tests work with these minimized configs
+ # tls is optional for bsi/nist but add it so verify tests work with these minimized configs
flags += ['--module-policy=%s' % (target),